#
# spec file for package chezscheme
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define chezscheme ChezScheme
%define srcext     tar.zst

Name:           chezscheme
Summary:        A superset of the R6RS Scheme language
Version:        10.1.0
Release:        3.1
License:        Apache-2.0 AND BSD-2-Clause AND GPL-2.0-only AND Zlib AND SUSE-GPL-2.0-with-linking-exception
Group:          Development/Languages/Scheme
Source0:        %{chezscheme}-v%{version}.%{srcext}
URL:            https://cisco.github.io/ChezScheme/
BuildRequires:  fdupes
BuildRequires:  libX11-devel
BuildRequires:  liblz4-devel
BuildRequires:  libuuid-devel
BuildRequires:  ncurses-devel
BuildRequires:  unzip
BuildRequires:  zlib-devel

%description
Chez Scheme is an implementation of the Revised6 Report on Scheme (R6RS) with numerous language and programming environment extensions.

%package petite
Summary:        Faster interpret version of ChezScheme
Group:          Development/Languages/Scheme

%description petite
Petite Chez Scheme is a complete Scheme system that is fully compatible with Chez Scheme but uses a fast interpreter in place of the compiler.

%prep
cd %{_builddir}
%setup -q -n %{chezscheme}-v%{version}
# use system libs
rm -r lz4 zlib

# Patch the Makefile
# sed -i 's/-Werror//' ./c/Mf-ta6le
# Patch the expeditor.c
sed -i 's/xlocale\.h/locale.h/' ./c/expeditor.c

%build
# from https://src.fedoraproject.org/rpms/chez-scheme/blob/rawhide/f/chez-scheme.spec
case %{_arch} in
     x86_64) MACHINE=-m=ta6le ;;
     i686) MACHINE=-m=ti3le ;;
     aarch64) MACHINE=-m=tarm64le ;;
     riscv64) MACHINE=-m=trv64le ;;
     *) MACHINE=--pb ;;
esac

./configure --installprefix=/usr  --temproot=%{buildroot} --threads $MACHINE  ZLIB=-lz LZ4=-llz4

%make_build

%install
%makeinstall

# de-duplicate scheme-script.boot and scheme.boot
br_s_script=$(find %{buildroot} -name scheme-script.boot)
s_boot=$(cd %{buildroot} && find usr -name scheme.boot)
rm "$br_s_script"
ln -s "/$s_boot" "$br_s_script"

%fdupes %{buildroot}

%files
%defattr(-,root,root)
%doc %{_mandir}/man1/scheme.1*
%{_bindir}/scheme
%{_bindir}/scheme-script
/usr/lib/csv%{version}

%files petite
%defattr(-,root,root)
%{_bindir}/petite
%doc %{_mandir}/man1/petite.1*

%changelog
* Sun Apr 20 2025 Christian Boltz <suse-beta@cboltz.de>
- build for all architectures, not only x86_64
- use system liblz4 and zlib
* Thu Jan  2 2025 Xu Zhao <i@xuzhao.net>
- remove redundant submodule source files
* Sat Dec 28 2024 Xu Zhao <i@xuzhao.net>
- use obs_scm to manage source files
* Sat Dec 28 2024 Xu Zhao <i@xuzhao.net>
- update to version 10.1.0
  * Updates and bug fixes since February 1, 2024.
- update lz4 to 5ff839680134437dbf4678f3d0c7b371d84f4964
* Mon Feb 12 2024 Xu Zhao <i@xuzhao.net>
- update to version 10.0.0
  * Updates and bug fixes since October 16, 2023.
- add new dependency zuo
* Mon Oct 16 2023 Lubos Kocman <lubos.kocman@suse.com>
- License correction based on legaldb review
* Mon Sep 11 2023 Xu Zhao <i@xuzhao.net>
- update to version 9.6.2
  * Updates and bug fixes since April 25, 2022.
* Sun Jul 23 2023 Xu Zhao <i@xuzhao.net>
- update to version 9.5.8a
  * Updates and bug fixes since November 5, 2021.
* Mon May 30 2022 Xu Zhao <i@xuzhao.net>
- update to version 9.5.8
* Tue Mar 29 2022 Xu Zhao <i@xuzhao.net>
- update to version 9.5.6
* Mon Nov 16 2020 Xu Zhao <i@xuzhao.net>
- update to version 9.5.4
* Mon May 13 2019 Rony Reis <reis@sapo.pt>
- updated version to 9.5.2
* Sun Jan 13 2019 Xu Zhao <i@xuzhao.net>
- updated version to 9.5
- updated release notes and fixed user's guide overfull hbox.
  * release-notes.stex, syntax.stex
- updated install target to do something more sensible release_notes/Makefile
